@@ -286,7 +286,6 @@ class TestIosBgpGlobalModule(TestIosModule):
              timers bgp 100 200 150
              redistribute connected metric 10
              neighbor 192.0.2.1 remote-as 100
-             neighbor 192.0.2.1 route-map test-route out
              address-family ipv4
               neighbor 192.0.2.28 activate
               neighbor 172.31.35.140 activate
@@ -304,9 +303,8 @@ class TestIosBgpGlobalModule(TestIosModule):
                     redistribute=[dict(connected=dict(set=True, metric=10))],
                     neighbors=[
                         dict(
-                            address="192.0.2.1",
+                            neighbor_address="192.0.2.1",
                             remote_as=100,
-                            route_map=dict(name="test-route", out=True),
                         ),
                     ],
                     timers=dict(keepalive=100, holdtime=200, min_holdtime=150),
@@ -316,6 +314,34 @@ class TestIosBgpGlobalModule(TestIosModule):
         )
         self.execute_module(changed=False, commands=[])
 
+    def test_ios_bgp_global_ebgp_multihop(self):
+        self.execute_show_command.return_value = dedent(
+            """\
+            router bgp 65000
+             neighbor 192.0.2.1 remote-as 100
+             neighbor 192.0.2.1 ebgp-multihop 255
+            """,
+        )
+        set_module_args(
+            {
+                "config": {
+                    "as_number": "65000",
+                    "neighbors": [
+                        {
+                            "neighbor_address": "192.0.2.1",
+                            "remote_as": "100",
+                            "ebgp_multihop": {
+                                "enable": True,
+                                "hop_count": 255,
+                            },
+                        },
+                    ],
+                },
+                "state": "merged",
+            },
+        )
+        self.execute_module(changed=False, commands=[])
+
     def test_ios_bgp_global_merged_fail_msg(self):
         self.execute_show_command.return_value = dedent(
             """\
@@ -326,7 +352,6 @@ class TestIosBgpGlobalModule(TestIosModule):
              timers bgp 100 200 150
              redistribute connected metric 10
              neighbor 192.0.2.1 remote-as 100
-             neighbor 192.0.2.1 route-map test-route out
              address-family ipv4
               neighbor 192.0.2.28 activate
               neighbor 172.31.35.140 activate
@@ -344,9 +369,8 @@ class TestIosBgpGlobalModule(TestIosModule):
                     redistribute=[dict(connected=dict(set=True, metric=10))],
                     neighbors=[
                         dict(
-                            address="192.0.2.1",
+                            neighbor_address="192.0.2.1",
                             remote_as=100,
-                            route_map=dict(name="test-route", out=True),
                         ),
                     ],
                     timers=dict(keepalive=100, holdtime=200, min_holdtime=150),
@@ -368,7 +392,6 @@ class TestIosBgpGlobalModule(TestIosModule):
              bgp nopeerup-delay post-boot 10
              bgp bestpath compare-routerid
              bgp advertise-best-external
-             aggregate-address 192.168.0.11 255.255.0.0 attribute-map map1
              timers bgp 100 200 150
              redistribute connected metric 10
              neighbor 192.0.2.2 remote-as 100
@@ -382,13 +405,6 @@ class TestIosBgpGlobalModule(TestIosModule):
             dict(
                 config=dict(
                     as_number="65000",
-                    aggregate_address=dict(
-                        dict(
-                            address="192.168.0.11",
-                            attribute_map="map1",
-                            netmask="255.255.0.0",
-                        ),
-                    ),
                     aggregate_addresses=[
                         dict(
                             address="192.168.0.1",
@@ -410,7 +426,7 @@ class TestIosBgpGlobalModule(TestIosModule):
                     redistribute=[dict(connected=dict(set=True, metric=10))],
                     neighbors=[
                         dict(
-                            address="192.0.2.1",
+                            neighbor_address="192.0.2.1",
                             remote_as=200,
                             description="replace neighbor",
                         ),
@@ -440,7 +456,6 @@ class TestIosBgpGlobalModule(TestIosModule):
              bgp nopeerup-delay post-boot 10
              bgp bestpath compare-routerid
              bgp advertise-best-external
-             aggregate-address 192.168.0.11 255.255.0.0 attribute-map map1
              timers bgp 100 200 150
              redistribute connected metric 10
              neighbor 192.0.2.2 remote-as 100
@@ -454,13 +469,6 @@ class TestIosBgpGlobalModule(TestIosModule):
             dict(
                 config=dict(
                     as_number="65000",
-                    aggregate_address=dict(
-                        dict(
-                            address="192.168.0.11",
-                            attribute_map="map1",
-                            netmask="255.255.0.0",
-                        ),
-                    ),
                     aggregate_addresses=[
                         dict(
                             address="192.168.0.1",
@@ -486,7 +494,7 @@ class TestIosBgpGlobalModule(TestIosModule):
                     redistribute=[dict(connected=dict(set=True, metric=10))],
                     neighbors=[
                         dict(
-                            address="192.0.2.1",
+                            neighbor_address="192.0.2.1",
                             remote_as=200,
                             description="replace neighbor",
                         ),
@@ -520,7 +528,6 @@ class TestIosBgpGlobalModule(TestIosModule):
              timers bgp 100 200 150
              redistribute connected metric 10
              neighbor 192.0.2.1 remote-as 100
-             neighbor 192.0.2.1 route-map test-route out
              address-family ipv4
               neighbor 192.0.2.28 activate
               neighbor 172.31.35.140 activate
@@ -538,9 +545,8 @@ class TestIosBgpGlobalModule(TestIosModule):
                     redistribute=[dict(connected=dict(set=True, metric=10))],
                     neighbors=[
                         dict(
-                            address="192.0.2.1",
+                            neighbor_address="192.0.2.1",
                             remote_as=100,
-                            route_map=dict(name="test-route", out=True),
                         ),
                     ],
                     timers=dict(keepalive=100, holdtime=200, min_holdtime=150),
@@ -610,220 +616,6 @@ class TestIosBgpGlobalModule(TestIosModule):
         commands = ["no router bgp 65000"]
         self.execute_module(changed=True, commands=commands)
 
-    def test_deprecated_attributes_rendered(self):
-        set_module_args(
-            {
-                "config": {
-                    "aggregate_address": {
-                        "address": "192.0.2.3",
-                        "attribute_map": "ma",
-                        "netmask": "255.255.0.0",
-                        "summary_only": True,
-                    },
-                    "as_number": "65000",
-                    "auto_summary": True,
-                    "bgp": {
-                        "additional_paths": {"install": True, "receive": True},
-                        "bestpath": [
-                            {"aigp": True},
-                            {"compare_routerid": True},
-                            {"med": {"confed": True, "missing_as_worst": True}},
-                        ],
-                        "inject_map": {
-                            "copy_attributes": True,
-                            "exist_map_name": "mp2",
-                            "name": "map1",
-                        },
-                        "listen": {
-                            "limit": 200,
-                            "range": {
-                                "ipv4_with_subnet": "192.0.2.9/24",
-                                "peer_group": "mygrp",
-                            },
-                        },
-                        "log_neighbor_changes": True,
-                        "nopeerup_delay": [
-                            {
-                                "cold_boot": 2,
-                                "nsf_switchover": 10,
-                                "post_boot": 22,
-                                "user_initiated": 22,
-                            },
-                        ],
-                    },
-                    "bmp": {"buffer_size": 22, "server": 2},
-                    "distance": {
-                        "bgp": {
-                            "routes_external": 2,
-                            "routes_internal": 3,
-                            "routes_local": 4,
-                        },
-                        "mbgp": {
-                            "routes_external": 2,
-                            "routes_internal": 3,
-                            "routes_local": 5,
-                        },
-                    },
-                    "distribute_list": {
-                        "out": True,
-                        "acl": "5000",
-                        "interface": "Loopback0",
-                    },
-                    "maximum_paths": {"ibgp": 2, "paths": 2},
-                    "maximum_secondary_paths": {"ibgp": 22, "paths": 22},
-                    "neighbors": [
-                        {
-                            "advertise": {"diverse_path": {"backup": True}},
-                            "neighbor_address": "192.1.1.1",
-                            "route_reflector_client": True,
-                        },
-                        {
-                            "neighbor_address": "192.5.5.5",
-                            "remote_as": 64500,
-                            "update_source": "Loopback0",
-                            "route_map": {"name": "rmp1", "in": True},
-                        },
-                        {
-                            "neighbor_address": "192.6.6.6",
-                            "remote_as": 64500,
-                            "update_source": "Loop",
-                        },
-                        {
-                            "neighbor_address": "192.1.1.2",
-                            "local_as": {
-                                "no_prepend": {"replace_as": True, "set": True},
-                                "number": 56,
-                                "set": True,
-                            },
-                        },
-                        {
-                            "activate": True,
-                            "address": "192.0.1.2",
-                            "remote_as": 45000,
-                            "send_community": {"extended": True},
-                            "password": "new password",
-                        },
-                        {
-                            "activate": True,
-                            "neighbor_address": "172.21.1.2",
-                            "remote_as": 45000,
-                        },
-                        {"neighbor_address": "192.0.2.3", "remote_as": 300},
-                        {
-                            "neighbor_address": "192.0.2.4",
-                            "remote_as": 6553601,
-                            "shutdown": {"set": True, "graceful": 10, "community": 20},
-                        },
-                        {
-                            "activate": True,
-                            "advertise": {"additional_paths": {"group_best": True}},
-                            "ipv6_adddress": "2001:DB8::1037",
-                        },
-                        {
-                            "tag": "tagged",
-                            "peer_group": "5",
-                            "soft_reconfiguration": True,
-                            "version": 4,
-                        },
-                    ],
-                    "networks": [
-                        {
-                            "address": "192.0.2.1",
-                            "backdoor": True,
-                            "netmask": "55.255.0.0",
-                            "route_map": "mp1",
-                        },
-                        {
-                            "address": "192.0.2.3",
-                            "backdoor": True,
-                            "netmask": "255.255.0.0",
-                            "route_map": "mp2",
-                        },
-                        {
-                            "address": "192.0.2.0",
-                            "backdoor": True,
-                            "netmask": "255.255.0.0",
-                            "route_map": "mp2",
-                        },
-                    ],
-                    "redistribute": [
-                        {"static": {"metric": 33, "route_map": "mp1"}},
-                        {"application": {"metric": 22, "name": "ap1"}},
-                        {
-                            "application": {
-                                "metric": 33,
-                                "name": "ap112",
-                                "route_map": "mp1",
-                            },
-                        },
-                        {"connected": {"metric": 22}},
-                        {"mobile": {"metric": 211}},
-                    ],
-                    "route_server_context": {"description": "good smn server BMP"},
-                },
-                "state": "rendered",
-            },
-        )
-        commands = [
-            "router bgp 65000",
-            "auto-summary",
-            "bmp buffer-size 22",
-            "bmp server 2",
-            "distance bgp 2 3 4",
-            "distance mbgp 2 3 5",
-            "maximum-paths 2",
-            "maximum-paths ibgp 2",
-            "maximum-secondary-paths 22",
-            "maximum-secondary-paths ibgp 22",
-            "description good smn server BMP",
-            "bgp additional-paths install receive",
-            "bgp bestpath aigp ignore",
-            "bgp bestpath compare-routerid",
-            "bgp bestpath med confed missing-as-worst",
-            "bgp listen limit 200",
-            "bgp listen range 192.0.2.9/24 peer-group mygrp",
-            "bgp log-neighbor-changes",
-            "bgp nopeerup-delay cold-boot 2",
-            "bgp nopeerup-delay post-boot 22",
-            "bgp nopeerup-delay nsf-switchover 10",
-            "bgp nopeerup-delay user-initiated 22",
-            "bgp inject-map map1 exist-map mp2 copy-attributes",
-            "distribute-list 5000 out Loopback0",
-            "aggregate-address 192.0.2.3 255.255.0.0 summary-only attribute-map ma",
-            "network 192.0.2.1 mask 55.255.0.0 route-map mp1 backdoor",
-            "network 192.0.2.3 mask 255.255.0.0 route-map mp2 backdoor",
-            "network 192.0.2.0 mask 255.255.0.0 route-map mp2 backdoor",
-            "neighbor 192.1.1.1 advertise diverse-path backup",
-            "neighbor 192.1.1.1 route-reflector-client",
-            "neighbor 192.5.5.5 remote-as 64500",
-            "neighbor 192.5.5.5 update-source Loopback0",
-            "neighbor 192.5.5.5 route-map rmp1 in",
-            "neighbor 192.6.6.6 remote-as 64500",
-            "neighbor 192.6.6.6 update-source Loop",
-            "neighbor 192.1.1.2 local-as 56 no-prepend replace-as",
-            "neighbor 192.0.1.2 remote-as 45000",
-            "neighbor 192.0.1.2 password new password",
-            "neighbor 192.0.1.2 activate",
-            "neighbor 192.0.1.2 send-community extended",
-            "neighbor 172.21.1.2 remote-as 45000",
-            "neighbor 172.21.1.2 activate",
-            "neighbor 192.0.2.3 remote-as 300",
-            "neighbor 192.0.2.4 remote-as 6553601",
-            "neighbor 192.0.2.4 shutdown graceful 10 community 20",
-            "neighbor 2001:DB8::1037 activate",
-            "neighbor 2001:DB8::1037 advertise additional-paths group-best",
-            "neighbor tagged peer-group 5",
-            "neighbor tagged soft-reconfiguration inbound",
-            "neighbor tagged version 4",
-            "redistribute static metric 33 route-map mp1",
-            "redistribute application ap1 metric 22",
-            "redistribute application ap112 metric 33 route-map mp1",
-            "redistribute connected metric 22",
-            "redistribute mobile metric 211",
-        ]
-        result = self.execute_module(changed=False)
-        self.assertEqual(sorted(result["rendered"]), sorted(commands))
-
     def test_ios_bgp_global_parsed(self):
         set_module_args(
             dict(
@@ -836,6 +628,7 @@ class TestIosBgpGlobalModule(TestIosModule):
                      timers bgp 100 200 150
                      redistribute connected metric 10
                      neighbor 192.0.2.1 remote-as 100
+                     neighbor 192.0.2.1 password 7 DEQPITOP101395
                      neighbor 192.0.2.1 route-map test-route out
                      address-family ipv4
                       neighbor 192.0.2.28 activate
@@ -860,7 +653,13 @@ class TestIosBgpGlobalModule(TestIosModule):
                 {
                     "remote_as": "100",
                     "neighbor_address": "192.0.2.1",
-                    "route_maps": [{"name": "test-route", "out": True}],
+                    "route_maps": [
+                        {"name": "test-route", "out": True},
+                    ],
+                    "password_options": {
+                        "encryption": 7,
+                        "pass_key": "DEQPITOP101395",
+                    },
                 },
             ],
         }
