@@ -4,93 +4,128 @@
 # (c) 2015, Leendert Brouwer (https://github.com/objectified)
 # (c) 2015, Toshio Kuratomi <tkuratomi@ansible.com>
 # Copyright (c) 2017 Ansible Project
-# GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
+# GNU General Public License v3.0+ (see LICENSES/GPL-3.0-or-later.txt or https://www.gnu.org/licenses/gpl-3.0.txt)
+# SPDX-License-Identifier: GPL-3.0-or-later
 
 from __future__ import (absolute_import, division, print_function)
 __metaclass__ = type
 
-DOCUMENTATION = '''
-    author:
-        - Lorin Hochestein (!UNKNOWN)
-        - Leendert Brouwer (!UNKNOWN)
-    name: docker
-    short_description: Run tasks in docker containers
+DOCUMENTATION = r"""
+author:
+  - Lorin Hochestein (!UNKNOWN)
+  - Leendert Brouwer (!UNKNOWN)
+name: docker
+short_description: Run tasks in docker containers
+description:
+  - Run commands or put/fetch files to an existing docker container.
+  - Uses the Docker CLI to execute commands in the container. If you prefer to directly connect to the Docker daemon, use
+    the P(community.docker.docker_api#connection) connection plugin.
+options:
+  remote_addr:
     description:
-        - Run commands or put/fetch files to an existing docker container.
-        - Uses the Docker CLI to execute commands in the container. If you prefer
-          to directly connect to the Docker daemon, use the
-          R(community.docker.docker_api,ansible_collections.community.docker.docker_api_connection)
-          connection plugin.
-    options:
-      remote_addr:
-        description:
-            - The name of the container you want to access.
-        default: inventory_hostname
-        vars:
-            - name: inventory_hostname
-            - name: ansible_host
-            - name: ansible_docker_host
-      remote_user:
-        description:
-            - The user to execute as inside the container.
-            - If Docker is too old to allow this (< 1.7), the one set by Docker itself will be used.
-        vars:
-            - name: ansible_user
-            - name: ansible_docker_user
-        ini:
-            - section: defaults
-              key: remote_user
-        env:
-            - name: ANSIBLE_REMOTE_USER
-        cli:
-            - name: user
-        keyword:
-            - name: remote_user
-      docker_extra_args:
-        description:
-            - Extra arguments to pass to the docker command line.
-        default: ''
-        vars:
-            - name: ansible_docker_extra_args
-        ini:
-            - section: docker_connection
-              key: extra_cli_args
-      container_timeout:
-        default: 10
-        description:
-            - Controls how long we can wait to access reading output from the container once execution started.
-        env:
-            - name: ANSIBLE_TIMEOUT
-            - name: ANSIBLE_DOCKER_TIMEOUT
-              version_added: 2.2.0
-        ini:
-            - key: timeout
-              section: defaults
-            - key: timeout
-              section: docker_connection
-              version_added: 2.2.0
-        vars:
-          - name: ansible_docker_timeout
-            version_added: 2.2.0
-        cli:
-          - name: timeout
-        type: integer
-'''
+      - The name of the container you want to access.
+    default: inventory_hostname
+    vars:
+      - name: inventory_hostname
+      - name: ansible_host
+      - name: ansible_docker_host
+  remote_user:
+    description:
+      - The user to execute as inside the container.
+      - If Docker is too old to allow this (< 1.7), the one set by Docker itself will be used.
+    vars:
+      - name: ansible_user
+      - name: ansible_docker_user
+    ini:
+      - section: defaults
+        key: remote_user
+    env:
+      - name: ANSIBLE_REMOTE_USER
+    cli:
+      - name: user
+    keyword:
+      - name: remote_user
+  docker_extra_args:
+    description:
+      - Extra arguments to pass to the docker command line.
+    default: ''
+    vars:
+      - name: ansible_docker_extra_args
+    ini:
+      - section: docker_connection
+        key: extra_cli_args
+  container_timeout:
+    default: 10
+    description:
+      - Controls how long we can wait to access reading output from the container once execution started.
+    env:
+      - name: ANSIBLE_TIMEOUT
+      - name: ANSIBLE_DOCKER_TIMEOUT
+        version_added: 2.2.0
+    ini:
+      - key: timeout
+        section: defaults
+      - key: timeout
+        section: docker_connection
+        version_added: 2.2.0
+    vars:
+      - name: ansible_docker_timeout
+        version_added: 2.2.0
+    cli:
+      - name: timeout
+    type: integer
+  extra_env:
+    description:
+      - Provide extra environment variables to set when running commands in the Docker container.
+      - This option can currently only be provided as Ansible variables due to limitations of ansible-core's configuration
+        manager.
+    vars:
+      - name: ansible_docker_extra_env
+    type: dict
+    version_added: 3.12.0
+  working_dir:
+    description:
+      - The directory inside the container to run commands in.
+      - Requires Docker CLI version 18.06 or later.
+    env:
+      - name: ANSIBLE_DOCKER_WORKING_DIR
+    ini:
+      - key: working_dir
+        section: docker_connection
+    vars:
+      - name: ansible_docker_working_dir
+    type: string
+    version_added: 3.12.0
+  privileged:
+    description:
+      - Whether commands should be run with extended privileges.
+      - B(Note) that this allows command to potentially break out of the container. Use with care!
+    env:
+      - name: ANSIBLE_DOCKER_PRIVILEGED
+    ini:
+      - key: privileged
+        section: docker_connection
+    vars:
+      - name: ansible_docker_privileged
+    type: boolean
+    default: false
+    version_added: 3.12.0
+"""
 
 import fcntl
 import os
 import os.path
 import subprocess
 import re
+from shlex import quote as shlex_quote
 
-from ansible.compat import selectors
-from ansible.errors import AnsibleError, AnsibleFileNotFound
-from ansible.module_utils.six.moves import shlex_quote
+from ansible.errors import AnsibleError, AnsibleFileNotFound, AnsibleConnectionFailure
 from ansible.module_utils.common.process import get_bin_path
 from ansible.module_utils.common.text.converters import to_bytes, to_native, to_text
 from ansible.plugins.connection import ConnectionBase, BUFSIZE
 from ansible.utils.display import Display
 
+from ansible_collections.community.docker.plugins.module_utils.selectors import selectors
 from ansible_collections.community.docker.plugins.module_utils.version import LooseVersion
 
 display = Display()
@@ -108,7 +143,7 @@ class Connection(ConnectionBase):
         # Note: docker supports running as non-root in some configurations.
         # (For instance, setting the UNIX socket file to be readable and
         # writable by a specific UNIX group and then putting users into that
-        # group).  Therefore we don't check that the user is root when using
+        # group).  Therefore we do not check that the user is root when using
         # this connection.  But if the user is getting a permission denied
         # error it probably means that docker on their system is only
         # configured to be connected to by root and they are not running as
@@ -116,6 +151,7 @@ class Connection(ConnectionBase):
 
         self._docker_args = []
         self._container_user_cache = {}
+        self._version = None
 
         # Windows uses Powershell modules
         if getattr(self._shell, "_IS_WINDOWS", False):
@@ -129,12 +165,6 @@ class Connection(ConnectionBase):
             except ValueError:
                 raise AnsibleError("docker command not found in PATH")
 
-        self.docker_version = self._get_docker_version()
-        if self.docker_version == u'dev':
-            display.warning(u'Docker version number is "dev". Will assume latest version.')
-        if self.docker_version != u'dev' and LooseVersion(self.docker_version) < LooseVersion(u'1.3'):
-            raise AnsibleError('docker connection type requires docker 1.3 or higher')
-
     @staticmethod
     def _sanitize_version(version):
         version = re.sub(u'[^0-9a-zA-Z.]', u'', version)
@@ -215,21 +245,47 @@ class Connection(ConnectionBase):
         if self.remote_user is not None:
             local_cmd += [b'-u', self.remote_user]
 
+        if self.get_option('extra_env'):
+            for k, v in self.get_option('extra_env').items():
+                for val, what in ((k, 'Key'), (v, 'Value')):
+                    if not isinstance(val, str):
+                        raise AnsibleConnectionFailure(
+                            'Non-string {0} found for extra_env option. Ambiguous env options must be '
+                            'wrapped in quotes to avoid them being interpreted. {1}: {2!r}'
+                            .format(what.lower(), what, val)
+                        )
+                local_cmd += [b'-e', b'%s=%s' % (to_bytes(k, errors='surrogate_or_strict'), to_bytes(v, errors='surrogate_or_strict'))]
+
+        if self.get_option('working_dir') is not None:
+            local_cmd += [b'-w', to_bytes(self.get_option('working_dir'), errors='surrogate_or_strict')]
+            if self.docker_version != u'dev' and LooseVersion(self.docker_version) < LooseVersion(u'18.06'):
+                # https://github.com/docker/cli/pull/732, first appeared in release 18.06.0
+                raise AnsibleConnectionFailure(
+                    'Providing the working directory requires Docker CLI version 18.06 or newer. You have Docker CLI version {0}.'
+                    .format(self.docker_version)
+                )
+
+        if self.get_option('privileged'):
+            local_cmd += [b'--privileged']
+
         # -i is needed to keep stdin open which allows pipelining to work
         local_cmd += [b'-i', self.get_option('remote_addr')] + cmd
 
         return local_cmd
 
+    def _set_docker_args(self):
+        # TODO: this is mostly for backwards compatibility, play_context is used as fallback for older versions
+        # docker arguments
+        del self._docker_args[:]
+        extra_args = self.get_option('docker_extra_args') or getattr(self._play_context, 'docker_extra_args', '')
+        if extra_args:
+            self._docker_args += extra_args.split(' ')
+
     def _set_conn_data(self):
 
         ''' initialize for the connection, cannot do only in init since all data is not ready at that point '''
 
-        # TODO: this is mostly for backwards compatibility, play_context is used as fallback for older versions
-        # docker arguments
-        del self._docker_args[:]
-        extra_args = self.get_option('docker_extra_args') or self._play_context.docker_extra_args
-        if extra_args:
-            self._docker_args += extra_args.split(' ')
+        self._set_docker_args()
 
         self.remote_user = self.get_option('remote_user')
         if self.remote_user is None and self._play_context.remote_user is not None:
@@ -240,6 +296,19 @@ class Connection(ConnectionBase):
         if self.timeout == 10 and self.timeout != self._play_context.timeout:
             self.timeout = self._play_context.timeout
 
+    @property
+    def docker_version(self):
+
+        if not self._version:
+            self._set_docker_args()
+
+            self._version = self._get_docker_version()
+            if self._version == u'dev':
+                display.warning(u'Docker version number is "dev". Will assume latest version.')
+            if self._version != u'dev' and LooseVersion(self._version) < LooseVersion(u'1.3'):
+                raise AnsibleError('docker connection type requires docker 1.3 or higher')
+        return self._version
+
     def _get_actual_user(self):
         if self.remote_user is not None:
             # An explicit user is provided
@@ -251,12 +320,12 @@ class Connection(ConnectionBase):
                 actual_user = self._get_docker_remote_user()
                 if actual_user != self.get_option('remote_user'):
                     display.warning(u'docker {0} does not support remote_user, using container default: {1}'
-                                    .format(self.docker_version, self.actual_user or u'?'))
+                                    .format(self.docker_version, actual_user or u'?'))
                 return actual_user
         elif self._display.verbosity > 2:
-            # Since we're not setting the actual_user, look it up so we have it for logging later
+            # Since we are not setting the actual_user, look it up so we have it for logging later
             # Only do this if display verbosity is high enough that we'll need the value
-            # This saves overhead from calling into docker when we don't need to.
+            # This saves overhead from calling into docker when we do not need to.
             return self._get_docker_remote_user()
         else:
             return None
@@ -309,16 +378,21 @@ class Connection(ConnectionBase):
                         stdout, stderr = p.communicate()
                         raise AnsibleError('timeout waiting for privilege escalation password prompt:\n' + to_native(become_output))
 
+                    chunks = b""
                     for key, event in events:
                         if key.fileobj == p.stdout:
                             chunk = p.stdout.read()
+                            if chunk:
+                                chunks += chunk
                         elif key.fileobj == p.stderr:
                             chunk = p.stderr.read()
+                            if chunk:
+                                chunks += chunk
 
-                    if not chunk:
+                    if not chunks:
                         stdout, stderr = p.communicate()
                         raise AnsibleError('privilege output closed while waiting for password prompt:\n' + to_native(become_output))
-                    become_output += chunk
+                    become_output += chunks
             finally:
                 selector.close()
 
@@ -339,11 +413,11 @@ class Connection(ConnectionBase):
         ''' Make sure that we put files into a standard path
 
             If a path is relative, then we need to choose where to put it.
-            ssh chooses $HOME but we aren't guaranteed that a home dir will
-            exist in any given chroot.  So for now we're choosing "/" instead.
+            ssh chooses $HOME but we are not guaranteed that a home dir will
+            exist in any given chroot.  So for now we are choosing "/" instead.
             This also happens to be the former default.
 
-            Can revisit using $HOME instead if it's a problem
+            Can revisit using $HOME instead if it is a problem
         '''
         if getattr(self._shell, "_IS_WINDOWS", False):
             import ntpath
@@ -365,7 +439,7 @@ class Connection(ConnectionBase):
                 "file or module does not exist: %s" % to_native(in_path))
 
         out_path = shlex_quote(out_path)
-        # Older docker doesn't have native support for copying files into
+        # Older docker does not have native support for copying files into
         # running containers, so we use docker exec to implement this
         # Although docker version 1.8 and later provide support, the
         # owner and group of the files are always set to root
@@ -377,8 +451,7 @@ class Connection(ConnectionBase):
             args = self._build_exec_cmd([self._play_context.executable, "-c", "dd of=%s bs=%s%s" % (out_path, BUFSIZE, count)])
             args = [to_bytes(i, errors='surrogate_or_strict') for i in args]
             try:
-                p = subprocess.Popen(args, stdin=in_file,
-                                     stdout=subprocess.PIPE, stderr=subprocess.PIPE)
+                p = subprocess.Popen(args, stdin=in_file, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
             except OSError:
                 raise AnsibleError("docker connection requires dd command in the container to put files")
             stdout, stderr = p.communicate()
@@ -412,7 +485,7 @@ class Connection(ConnectionBase):
             actual_out_path = os.path.join(out_dir, os.path.basename(in_path))
 
         if p.returncode != 0:
-            # Older docker doesn't have native support for fetching files command `cp`
+            # Older docker does not have native support for fetching files command `cp`
             # If `cp` fails, try to use `dd` instead
             args = self._build_exec_cmd([self._play_context.executable, "-c", "dd if=%s bs=%s" % (in_path, BUFSIZE)])
             args = [to_bytes(i, errors='surrogate_or_strict') for i in args]
