@@ -1,26 +1,39 @@
 #!/usr/bin/python
 #
-# (c) 2016 Olaf Kilian <olaf.kilian@symanex.com>
-#          Chris Houseknecht, <house@redhat.com>
-#          James Tanner, <jtanner@redhat.com>
+# Copyright (c) 2016 Olaf Kilian <olaf.kilian@symanex.com>
+#                    Chris Houseknecht, <house@redhat.com>
+#                    James Tanner, <jtanner@redhat.com>
 #
-# GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
+# GNU General Public License v3.0+ (see LICENSES/GPL-3.0-or-later.txt or https://www.gnu.org/licenses/gpl-3.0.txt)
+# SPDX-License-Identifier: GPL-3.0-or-later
 
 from __future__ import absolute_import, division, print_function
 __metaclass__ = type
 
 
-DOCUMENTATION = '''
----
+DOCUMENTATION = r"""
 module: docker_login
-short_description: Log into a Docker registry.
+short_description: Log into a Docker registry
 description:
-    - Provides functionality similar to the C(docker login) command.
-    - Authenticate with a docker registry and add the credentials to your local Docker config file respectively the
-      credentials store associated to the registry. Adding the credentials to the config files resp. the credential
-      store allows future connections to the registry using tools such as Ansible's Docker modules, the Docker CLI
-      and Docker SDK for Python without needing to provide credentials.
-    - Running in check mode will perform the authentication without updating the config file.
+  - Provides functionality similar to the C(docker login) command.
+  - Authenticate with a docker registry and add the credentials to your local Docker config file respectively the credentials
+    store associated to the registry. Adding the credentials to the config files resp. the credential store allows future
+    connections to the registry using tools such as Ansible's Docker modules, the Docker CLI and Docker SDK for Python without
+    needing to provide credentials.
+  - Running in check mode will perform the authentication without updating the config file.
+extends_documentation_fragment:
+  - community.docker.docker.api_documentation
+  - community.docker.attributes
+  - community.docker.attributes.actiongroup_docker
+
+attributes:
+  check_mode:
+    support: full
+  diff_mode:
+    support: none
+  idempotent:
+    support: full
+
 options:
   registry_url:
     description:
@@ -33,18 +46,18 @@ options:
   username:
     description:
       - The username for the registry account.
-      - Required when I(state) is C(present).
+      - Required when O(state=present).
     type: str
   password:
     description:
       - The plaintext password for the registry account.
-      - Required when I(state) is C(present).
+      - Required when O(state=present).
     type: str
   reauthorize:
     description:
       - Refresh existing authentication found in the configuration file.
     type: bool
-    default: no
+    default: false
     aliases:
       - reauth
   config_path:
@@ -56,7 +69,7 @@ options:
       - dockercfg_path
   state:
     description:
-      - This controls the current state of the user. C(present) will login in a user, C(absent) will log them out.
+      - This controls the current state of the user. V(present) will login in a user, V(absent) will log them out.
       - To logout you only need the registry server, which defaults to DockerHub.
       - Before 2.1 you could ONLY log in.
       - Docker does not support 'logout' with a custom config file.
@@ -64,22 +77,15 @@ options:
     default: 'present'
     choices: ['present', 'absent']
 
-extends_documentation_fragment:
-- community.docker.docker
-- community.docker.docker.docker_py_1_documentation
-
 requirements:
-  - "L(Docker SDK for Python,https://docker-py.readthedocs.io/en/stable/) >= 1.8.0 (use L(docker-py,https://pypi.org/project/docker-py/) for Python 2.6)"
-  - "Python bindings for docker credentials store API >= 0.2.1
-    (use L(docker-pycreds,https://pypi.org/project/docker-pycreds/) when using Docker SDK for Python < 4.0.0)"
-  - "Docker API >= 1.20"
+  - "Docker API >= 1.25"
 author:
   - Olaf Kilian (@olsaki) <olaf.kilian@symanex.com>
   - Chris Houseknecht (@chouseknecht)
-'''
-
-EXAMPLES = '''
+"""
 
+EXAMPLES = r"""
+---
 - name: Log into DockerHub
   community.docker.docker_login:
     username: docker
@@ -90,7 +96,7 @@ EXAMPLES = '''
     registry_url: your.private.registry.io
     username: yourself
     password: secrets3
-    reauthorize: yes
+    reauthorize: true
 
 - name: Log into DockerHub using a custom config file
   community.docker.docker_login:
@@ -101,76 +107,37 @@ EXAMPLES = '''
 - name: Log out of DockerHub
   community.docker.docker_login:
     state: absent
-'''
+"""
 
-RETURN = '''
-login_results:
-    description: Results from the login.
-    returned: when state='present'
-    type: dict
-    sample: {
-        "serveraddress": "localhost:5000",
-        "username": "testuser"
-    }
-'''
+RETURN = r"""
+login_result:
+  description: Result from the login.
+  returned: when O(state=present)
+  type: dict
+  sample: {"serveraddress": "localhost:5000", "username": "testuser"}
+"""
 
 import base64
 import json
 import os
-import re
 import traceback
 
 from ansible.module_utils.common.text.converters import to_bytes, to_text, to_native
 
-try:
-    from docker.errors import DockerException
-    from docker import auth
-
-    # Earlier versions of docker/docker-py put decode_auth
-    # in docker.auth.auth instead of docker.auth
-    if hasattr(auth, 'decode_auth'):
-        from docker.auth import decode_auth
-    else:
-        from docker.auth.auth import decode_auth
-
-except ImportError:
-    # missing Docker SDK for Python handled in ansible.module_utils.docker.common
-    pass
-
-from ansible_collections.community.docker.plugins.module_utils.common import (
+from ansible_collections.community.docker.plugins.module_utils.common_api import (
     AnsibleDockerClient,
-    HAS_DOCKER_PY,
-    DEFAULT_DOCKER_REGISTRY,
-    DockerBaseClass,
     RequestException,
 )
+from ansible_collections.community.docker.plugins.module_utils.util import (
+    DEFAULT_DOCKER_REGISTRY,
+    DockerBaseClass,
+)
 
-NEEDS_DOCKER_PYCREDS = False
-
-# Early versions of docker/docker-py rely on docker-pycreds for
-# the credential store api.
-if HAS_DOCKER_PY:
-    try:
-        from docker.credentials.errors import StoreError, CredentialsNotFound
-        from docker.credentials import Store
-    except ImportError:
-        try:
-            from dockerpycreds.errors import StoreError, CredentialsNotFound
-            from dockerpycreds.store import Store
-        except ImportError as exc:
-            HAS_DOCKER_ERROR = str(exc)
-            NEEDS_DOCKER_PYCREDS = True
-
-
-if NEEDS_DOCKER_PYCREDS:
-    # docker-pycreds missing, so we need to create some place holder classes
-    # to allow instantiation.
-
-    class StoreError(Exception):
-        pass
-
-    class CredentialsNotFound(Exception):
-        pass
+from ansible_collections.community.docker.plugins.module_utils._api import auth
+from ansible_collections.community.docker.plugins.module_utils._api.auth import decode_auth
+from ansible_collections.community.docker.plugins.module_utils._api.credentials.errors import CredentialsNotFound
+from ansible_collections.community.docker.plugins.module_utils._api.credentials.store import Store
+from ansible_collections.community.docker.plugins.module_utils._api.errors import DockerException
 
 
 class DockerFileStore(object):
@@ -291,7 +258,7 @@ class LoginManager(DockerBaseClass):
 
     def run(self):
         '''
-        Do the actuall work of this task here. This allows instantiation for partial
+        Do the actual work of this task here. This allows instantiation for partial
         testing.
         '''
 
@@ -303,6 +270,34 @@ class LoginManager(DockerBaseClass):
     def fail(self, msg):
         self.client.fail(msg)
 
+    def _login(self, reauth):
+        if self.config_path and os.path.exists(self.config_path):
+            self.client._auth_configs = auth.load_config(
+                self.config_path, credstore_env=self.client.credstore_env
+            )
+        elif not self.client._auth_configs or self.client._auth_configs.is_empty:
+            self.client._auth_configs = auth.load_config(
+                credstore_env=self.client.credstore_env
+            )
+
+        authcfg = self.client._auth_configs.resolve_authconfig(self.registry_url)
+        # If we found an existing auth config for this registry and username
+        # combination, we can return it immediately unless reauth is requested.
+        if authcfg and authcfg.get('username') == self.username and not reauth:
+            return authcfg
+
+        req_data = {
+            'username': self.username,
+            'password': self.password,
+            'email': None,
+            'serveraddress': self.registry_url,
+        }
+
+        response = self.client._post_json(self.client._url('/auth'), data=req_data)
+        if response.status_code == 200:
+            self.client._auth_configs.add_auth(self.registry_url or auth.INDEX_NAME, req_data)
+        return self.client._result(response, json=True)
+
     def login(self):
         '''
         Log into the registry with provided username/password. On success update the config
@@ -314,30 +309,18 @@ class LoginManager(DockerBaseClass):
         self.results['actions'].append("Logged into %s" % (self.registry_url))
         self.log("Log into %s with username %s" % (self.registry_url, self.username))
         try:
-            response = self.client.login(
-                self.username,
-                password=self.password,
-                registry=self.registry_url,
-                reauth=self.reauthorize,
-                dockercfg_path=self.config_path
-            )
+            response = self._login(self.reauthorize)
         except Exception as exc:
             self.fail("Logging into %s for user %s failed - %s" % (self.registry_url, self.username, to_native(exc)))
 
         # If user is already logged in, then response contains password for user
         if 'password' in response:
             # This returns correct password if user is logged in and wrong password is given.
-            # So if it returns another password as we passed, and the user didn't request to
+            # So if it returns another password as we passed, and the user did not request to
             # reauthorize, still do it.
             if not self.reauthorize and response['password'] != self.password:
                 try:
-                    response = self.client.login(
-                        self.username,
-                        password=self.password,
-                        registry=self.registry_url,
-                        reauth=True,
-                        dockercfg_path=self.config_path
-                    )
+                    response = self._login(True)
                 except Exception as exc:
                     self.fail("Logging into %s for user %s failed - %s" % (self.registry_url, self.username, to_native(exc)))
             response.pop('password', None)
@@ -356,7 +339,7 @@ class LoginManager(DockerBaseClass):
         store = self.get_credential_store_instance(self.registry_url, self.config_path)
 
         try:
-            current = store.get(self.registry_url)
+            store.get(self.registry_url)
         except CredentialsNotFound:
             # get raises an exception on not found.
             self.log("Credentials for %s not present, doing nothing." % (self.registry_url))
@@ -403,20 +386,11 @@ class LoginManager(DockerBaseClass):
         :rtype: Union[docker.credentials.Store, NoneType]
         '''
 
-        # Older versions of docker-py don't have this feature.
-        try:
-            credstore_env = self.client.credstore_env
-        except AttributeError:
-            credstore_env = None
+        credstore_env = self.client.credstore_env
 
         config = auth.load_config(config_path=dockercfg_path)
 
-        if hasattr(auth, 'get_credential_store'):
-            store_name = auth.get_credential_store(config, registry)
-        elif 'credsStore' in config:
-            store_name = config['credsStore']
-        else:
-            store_name = None
+        store_name = auth.get_credential_store(config, registry)
 
         # Make sure that there is a credential helper before trying to instantiate a
         # Store object.
@@ -446,7 +420,6 @@ def main():
         argument_spec=argument_spec,
         supports_check_mode=True,
         required_if=required_if,
-        min_docker_api_version='1.20',
     )
 
     try:
@@ -463,10 +436,10 @@ def main():
             del results['actions']
         client.module.exit_json(**results)
     except DockerException as e:
-        client.fail('An unexpected docker error occurred: {0}'.format(to_native(e)), exception=traceback.format_exc())
+        client.fail('An unexpected Docker error occurred: {0}'.format(to_native(e)), exception=traceback.format_exc())
     except RequestException as e:
         client.fail(
-            'An unexpected requests error occurred when docker-py tried to talk to the docker daemon: {0}'.format(to_native(e)),
+            'An unexpected requests error occurred when trying to talk to the Docker daemon: {0}'.format(to_native(e)),
             exception=traceback.format_exc())
 
 
