@@ -83,11 +83,9 @@ options:
     version_added: "3.5.0"
   force_defaults:
     description:
-      - Overwrite current O(description) and O(private) attributes with defaults if set to V(true), which currently is the
-        default.
-      - The default for this option will be deprecated in a future version of this collection, and eventually change to V(false).
+      - If V(true), overwrite current O(description) and O(private) attributes with defaults.
+      - V(true) is deprecated for this option and will not be allowed starting in community.general 13.0.0. V(false) will be the default value then.
     type: bool
-    default: true
     required: false
     version_added: 4.1.0
 requirements:
@@ -246,13 +244,13 @@ def main():
         password=dict(type='str', no_log=True),
         access_token=dict(type='str', no_log=True),
         name=dict(type='str', required=True),
-        state=dict(type='str', required=False, default="present",
+        state=dict(type='str', default="present",
                    choices=["present", "absent"]),
-        organization=dict(type='str', required=False, default=None),
+        organization=dict(type='str', ),
         private=dict(type='bool'),
         description=dict(type='str'),
-        api_url=dict(type='str', required=False, default='https://api.github.com'),
-        force_defaults=dict(type='bool', default=True),
+        api_url=dict(type='str', default='https://api.github.com'),
+        force_defaults=dict(type='bool'),
     )
     module = AnsibleModule(
         argument_spec=module_args,
@@ -262,6 +260,11 @@ def main():
         mutually_exclusive=[('username', 'access_token')]
     )
 
+    if module.params['force_defaults'] is None:
+        module.deprecate("'force_defaults=true' is deprecated and will not be allowed in community.general 13.0.0, use 'force_defaults=false' instead",
+                         version="13.0.0", collection_name="community.general")
+        module.params['force_defaults'] = True
+
     if not HAS_GITHUB_PACKAGE:
         module.fail_json(msg=missing_required_lib(
             "PyGithub"), exception=GITHUB_IMP_ERR)
