@@ -7,7 +7,7 @@ __metaclass__ = type
 
 from .hpe_test_utils import FactsParamsTestCase
 
-from ansible_collections.community.general.tests.unit.compat import unittest
+from ansible_collections.community.internal_test_tools.tests.unit.compat import unittest
 from ansible_collections.community.general.plugins.modules.oneview_enclosure_info import EnclosureInfoModule
 
 
