@@ -86,9 +86,8 @@ DOCUMENTATION = r'''
         required: false
       vm_uuid:
         description:
+          - UUID of the virtual machine
           - Mutually exclusive with O(vm_path)
-          - VM UUID to the connection.
-          - UUID of the virtual machine from property config.uuid of P(community.vmware.vmware_vm_inventory#lookup) plugin
         vars:
           - name: ansible_vmware_guest_uuid
         required: false
@@ -233,7 +232,7 @@ except ImportError:
         HAS_URLLIB3 = False
 
 from ansible.errors import AnsibleError, AnsibleFileNotFound, AnsibleConnectionFailure
-from ansible.module_utils._text import to_bytes, to_native
+from ansible.module_utils.common.text.converters import to_bytes, to_native
 from ansible.plugins.connection import ConnectionBase
 from ansible.module_utils.basic import missing_required_lib
 
@@ -458,12 +457,13 @@ class Connection(ConnectionBase):
         Fix url if connection is a host.
 
         The host part of the URL is returned as '*' if the hostname to be used is the name of the server to which the call was made. For example, if the call is
-        made to esx-svr-1.domain1.com, and the file is available for download from http://esx-svr-1.domain1.com/guestFile?id=1&token=1234, the URL returned may
-        be http://*/guestFile?id=1&token=1234. The client replaces the asterisk with the server name on which it invoked the call.
+        made to esx-svr-1.domain1.com and port 443, and the file is available for download from http://esx-svr-1.domain1.com:443/guestFile?id=1&token=1234,
+        the URL returned may be http://*:443/guestFile?id=1&token=1234.
+        The client replaces the asterisk with the server name on which it invoked the call and 443 with the port number.
 
         https://code.vmware.com/apis/358/vsphere#/doc/vim.vm.guest.FileManager.FileTransferInformation.html
         """
-        return url.replace("*", self.vmware_host)
+        return url.replace("*", self.vmware_host).replace("443", str(self.get_option("vmware_port")))
 
     def _fetch_file_from_vm(self, guestFilePath):
         try:
