@@ -13,10 +13,13 @@ __metaclass__ = type
 DOCUMENTATION = r'''
 ---
 module: vmware_cluster_info
+deprecated:
+  removed_in: 7.0.0
+  why: This module has been moved to the L(new vmware.vmware collection,https://forum.ansible.com/t/5880)
+  alternative: Use M(vmware.vmware.cluster_info) instead.
 short_description: Gather info about clusters available in given vCenter
 description:
     - This module can be used to gather information about clusters in VMWare infrastructure.
-    - All values and VMware object names are case sensitive.
 author:
     - Abhijeet Kasurde (@Akasurde)
     - Christian Neugum (@digifuchsi)
@@ -24,26 +27,26 @@ options:
    datacenter:
      description:
      - Datacenter to search for cluster/s.
-     - This parameter is required, if C(cluster_name) is not supplied.
-     required: False
+     - This parameter is required, if O(cluster_name) is not supplied.
+     required: false
      type: str
    cluster_name:
      description:
      - Name of the cluster.
      - If set, information of this cluster will be returned.
-     - This parameter is required, if C(datacenter) is not supplied.
-     required: False
+     - This parameter is required, if O(datacenter) is not supplied.
+     required: false
      type: str
    show_tag:
     description:
-    - Tags related to cluster are shown if set to C(True).
-    default: False
+    - Tags related to cluster are shown if set to V(true).
+    default: false
     type: bool
    schema:
      description:
        - Specify the output schema desired.
-       - The 'summary' output schema is the legacy output from the module.
-       - The 'vsphere' output schema is the vSphere API class definition which requires pyvmomi>6.7.1.
+       - The V(summary) output schema is the legacy output from the module.
+       - The V(vsphere) output schema is the vSphere API class definition.
      choices: ['summary', 'vsphere']
      default: 'summary'
      type: str
@@ -56,7 +59,7 @@ options:
        - '      "configuration.dasConfig.enabled",'
        - '      "summary.totalCpu"'
        - '   ]'
-       - Only valid when C(schema) is C(vsphere).
+       - Only valid when O(schema=vsphere).
      type: list
      elements: str
 extends_documentation_fragment:
@@ -89,7 +92,7 @@ EXAMPLES = r'''
     username: '{{ vcenter_username }}'
     password: '{{ vcenter_password }}'
     cluster_name: DC0_C0
-    show_tag: True
+    show_tag: true
   delegate_to: localhost
   register: cluster_info
 
@@ -112,7 +115,6 @@ RETURN = r'''
 clusters:
     description:
       - metadata about the available clusters
-      - datacenter added in the return values from version 1.6.0
     returned: always
     type: dict
     sample: {
@@ -183,9 +185,9 @@ except ImportError:
     pass
 
 from ansible.module_utils.basic import AnsibleModule
-from ansible.module_utils.six.moves.urllib.parse import unquote
-from ansible_collections.community.vmware.plugins.module_utils.vmware import PyVmomi, vmware_argument_spec, find_datacenter_by_name, find_cluster_by_name,\
-    get_parent_datacenter
+from urllib.parse import unquote
+from ansible_collections.community.vmware.plugins.module_utils.vmware import PyVmomi, find_datacenter_by_name, find_cluster_by_name, get_parent_datacenter
+from ansible_collections.community.vmware.plugins.module_utils._argument_spec import base_argument_spec
 from ansible_collections.community.vmware.plugins.module_utils.vmware_rest_client import VmwareRestClient
 
 
@@ -263,12 +265,12 @@ class VmwreClusterInfoManager(PyVmomi):
                 if das_config.admissionControlPolicy:
                     ha_failover_level = das_config.admissionControlPolicy.failoverLevel
                 if das_config.defaultVmSettings:
-                    ha_restart_priority = das_config.defaultVmSettings.restartPriority,
-                    ha_vm_tools_monitoring = das_config.defaultVmSettings.vmToolsMonitoringSettings.vmMonitoring,
-                    ha_vm_min_up_time = das_config.defaultVmSettings.vmToolsMonitoringSettings.minUpTime,
-                    ha_vm_max_failures = das_config.defaultVmSettings.vmToolsMonitoringSettings.maxFailures,
-                    ha_vm_max_failure_window = das_config.defaultVmSettings.vmToolsMonitoringSettings.maxFailureWindow,
-                    ha_vm_failure_interval = das_config.defaultVmSettings.vmToolsMonitoringSettings.failureInterval,
+                    ha_restart_priority = das_config.defaultVmSettings.restartPriority
+                    ha_vm_tools_monitoring = das_config.defaultVmSettings.vmToolsMonitoringSettings.vmMonitoring
+                    ha_vm_min_up_time = das_config.defaultVmSettings.vmToolsMonitoringSettings.minUpTime
+                    ha_vm_max_failures = das_config.defaultVmSettings.vmToolsMonitoringSettings.maxFailures
+                    ha_vm_max_failure_window = das_config.defaultVmSettings.vmToolsMonitoringSettings.maxFailureWindow
+                    ha_vm_failure_interval = das_config.defaultVmSettings.vmToolsMonitoringSettings.failureInterval
 
                 # DRS
                 drs_config = cluster.configurationEx.drsConfig
@@ -320,7 +322,7 @@ class VmwreClusterInfoManager(PyVmomi):
 
 
 def main():
-    argument_spec = vmware_argument_spec()
+    argument_spec = base_argument_spec()
     argument_spec.update(
         datacenter=dict(type='str'),
         cluster_name=dict(type='str'),
