@@ -26,15 +26,15 @@ options:
     datacenter_name:
         description:
             - The name of the datacenter that will contain the Distributed Switch.
-            - This parameter is optional, if C(folder) is provided.
-            - Mutually exclusive with C(folder) parameter.
-        required: False
+            - Required if O(folder) is not provided.
+            - Mutually exclusive with O(folder) parameter.
+        required: false
         aliases: ['datacenter']
         type: str
     switch_name:
         description:
         - The name of the distribute vSwitch to create or remove.
-        required: True
+        required: true
         aliases: ['switch', 'dvswitch']
         type: str
     switch_version:
@@ -42,22 +42,21 @@ options:
             - The version of the Distributed Switch to create.
             - The version must match the version of the ESXi hosts you want to connect.
             - The version of the vCenter server is used if not specified.
-            - Required only if C(state) is set to C(present).
+            - Required if O(state=present).
         aliases: ['version']
         type: str
     mtu:
         description:
             - The switch maximum transmission unit.
-            - Required parameter for C(state) both C(present) and C(absent), before Ansible 2.6 version.
-            - Required only if C(state) is set to C(present), for Ansible 2.6 and onwards.
+            - Required if O(state=present).
             - Accepts value between 1280 to 9000 (both inclusive).
         type: int
         default: 1500
     multicast_filtering_mode:
         description:
             - The multicast filtering mode.
-            - 'C(basic) mode: multicast traffic for virtual machines is forwarded according to the destination MAC address of the multicast group.'
-            - 'C(snooping) mode: the Distributed Switch provides IGMP and MLD snooping according to RFC 4541.'
+            - 'V(basic) mode: multicast traffic for virtual machines is forwarded according to the destination MAC address of the multicast group.'
+            - 'V(snooping) mode: the Distributed Switch provides IGMP and MLD snooping according to RFC 4541.'
         type: str
         choices: ['basic', 'snooping']
         default: 'basic'
@@ -65,8 +64,7 @@ options:
         description:
             - Quantity of uplink per ESXi host added to the Distributed Switch.
             - The uplink quantity can be increased or decreased, but a decrease will only be successfull if the uplink isn't used by a portgroup.
-            - Required parameter for C(state) both C(present) and C(absent), before Ansible 2.6 version.
-            - Required only if C(state) is set to C(present), for Ansible 2.6 and onwards.
+            - Required if O(state=present).
         type: int
     uplink_prefix:
         description:
@@ -78,11 +76,10 @@ options:
     discovery_proto:
         description:
             - Link discovery protocol between Cisco and Link Layer discovery.
-            - Required parameter for C(state) both C(present) and C(absent), before Ansible 2.6 version.
-            - Required only if C(state) is set to C(present), for Ansible 2.6 and onwards.
-            - 'C(cdp): Use Cisco Discovery Protocol (CDP).'
-            - 'C(lldp): Use Link Layer Discovery Protocol (LLDP).'
-            - 'C(disabled): Do not use a discovery protocol.'
+            - Required if O(state=present).
+            - 'V(cdp): Use Cisco Discovery Protocol (CDP).'
+            - 'V(lldp): Use Link Layer Discovery Protocol (LLDP).'
+            - 'V(disabled): Do not use a discovery protocol.'
         choices: ['cdp', 'lldp', 'disabled']
         default: 'cdp'
         aliases: [ 'discovery_protocol' ]
@@ -90,8 +87,7 @@ options:
     discovery_operation:
         description:
             - Select the discovery operation.
-            - Required parameter for C(state) both C(present) and C(absent), before Ansible 2.6 version.
-            - Required only if C(state) is set to C(present), for Ansible 2.6 and onwards.
+            - Required if O(state=present).
         choices: ['both', 'advertise', 'listen']
         default: 'listen'
         type: str
@@ -117,11 +113,11 @@ options:
             vlan_mtu:
                 type: bool
                 description: VLAN and MTU health check.
-                default: False
+                default: false
             teaming_failover:
                 type: bool
                 description: Teaming and failover health check.
-                default: False
+                default: false
             vlan_mtu_interval:
                 type: int
                 description:
@@ -136,8 +132,8 @@ options:
                 default: 0
         type: dict
         default: {
-            vlan_mtu: False,
-            teaming_failover: False,
+            vlan_mtu: false,
+            teaming_failover: false,
             vlan_mtu_interval: 0,
             teaming_failover_interval: 0,
         }
@@ -149,21 +145,21 @@ options:
             promiscuous:
                 type: bool
                 description: Indicates whether promiscuous mode is allowed.
-                default: False
+                default: false
             forged_transmits:
                 type: bool
                 description: Indicates whether forged transmits are allowed.
-                default: False
+                default: false
             mac_changes:
                 type: bool
                 description: Indicates whether mac changes are allowed.
-                default: False
-        required: False
+                default: false
+        required: false
         type: dict
     state:
         description:
-            - If set to C(present) and the Distributed Switch does not exist, the Distributed Switch will be created.
-            - If set to C(absent) and the Distributed Switch exists, the Distributed Switch will be deleted.
+            - If set to V(present) and the Distributed Switch does not exist, the Distributed Switch will be created.
+            - If set to V(absent) and the Distributed Switch exists, the Distributed Switch will be deleted.
         default: 'present'
         choices: ['present', 'absent']
         type: str
@@ -171,8 +167,8 @@ options:
         description:
             - Destination folder, absolute path to place dvswitch in.
             - The folder should include the datacenter.
-            - This parameter is case sensitive.
-            - This parameter is optional, if C(datacenter) is provided.
+            - Required if O(datacenter) is not provided.
+            - Mutually exclusive with O(datacenter) parameter.
             - 'Examples:'
             - '   folder: /datacenter1/network'
             - '   folder: datacenter1/network'
@@ -181,10 +177,9 @@ options:
             - '   folder: /folder1/datacenter1/network'
             - '   folder: folder1/datacenter1/network'
             - '   folder: /folder1/datacenter1/network/folder2'
-        required: False
+        required: false
         type: str
     net_flow:
-        version_added: '2.7.0'
         description:
             - Dictionary which configures the Net Flow for the Distributed Switch.
         suboptions:
@@ -199,6 +194,13 @@ options:
                 type: int
                 description: Identifies the information related to the switch.
                 default: 0
+            switch_ip:
+                type: str
+                description:
+                    - Assign an IP address to see the distributed switch as a single network device in the NetFlow collector.
+                    - This is instead of as multiple devices corresponding to each host.
+                    - In an IPv6 environment, the ESXi hosts ignore the switch IP address.
+                version_added: '4.3.0'
             active_flow_timeout:
                 type: int
                 description: The time, in seconds, to wait before sending information after the flow is initiated.
@@ -218,7 +220,7 @@ options:
             internal_flows_only:
                 type: bool
                 description: If True, data on network activity between vms on the same host will be collected only.
-                default: False
+                default: false
         type: dict
         default: {
             'collector_port': 0,
@@ -226,7 +228,7 @@ options:
             'active_flow_timeout': 60,
             'idle_flow_timeout': 15,
             'sampling_rate': 4096,
-            'internal_flows_only': False
+            'internal_flows_only': false
         }
 extends_documentation_fragment:
 - community.vmware.vmware.documentation
@@ -272,10 +274,11 @@ EXAMPLES = r'''
         collector_ip: 192.168.10.50
         collector_port: 50034
         observation_domain_id: 0
+        switch_ip: 192.168.10.40
         active_flow_timeout: 60
         idle_flow_timeout: 15
         sampling_rate: 4096
-        internal_flows_only: False
+        internal_flows_only: false
     state: present
   delegate_to: localhost
 
@@ -310,10 +313,11 @@ result:
         "net_flow_collector_ip": "192.168.10.50",
         "net_flow_collector_port": 50034,
         "net_flow_observation_domain_id": 0,
+        "net_flow_switch_ip": "192.168.10.40",
         "net_flow_active_flow_timeout": 60,
         "net_flow_idle_flow_timeout": 15,
         "net_flow_sampling_rate": 4096,
-        "net_flow_internal_flows_only": False,
+        "net_flow_internal_flows_only": false,
         "mtu": 9000,
         "multicast_filtering_mode": "basic",
         "result": "DVS already configured properly",
@@ -332,10 +336,11 @@ except ImportError:
     pass
 
 from ansible.module_utils.basic import AnsibleModule
-from ansible.module_utils._text import to_native
+from ansible.module_utils.common.text.converters import to_native
 from ansible_collections.community.vmware.plugins.module_utils.vmware import (
-    PyVmomi, TaskError, find_dvs_by_name, vmware_argument_spec, wait_for_task
+    PyVmomi, TaskError, find_dvs_by_name, wait_for_task
 )
+from ansible_collections.community.vmware.plugins.module_utils._argument_spec import base_argument_spec
 
 
 class VMwareDvSwitch(PyVmomi):
@@ -397,6 +402,7 @@ class VMwareDvSwitch(PyVmomi):
         self.netFlow_collector_ip = self.module.params['net_flow'].get('collector_ip') or None
         self.netFlow_collector_port = self.module.params['net_flow'].get('collector_port')
         self.netFlow_observation_domain_id = self.module.params['net_flow'].get('observation_domain_id')
+        self.netFlow_switch_ip = self.module.params['net_flow'].get('switch_ip')
         self.netFlow_active_flow_timeout = self.module.params['net_flow'].get('active_flow_timeout')
         self.netFlow_idle_flow_timeout = self.module.params['net_flow'].get('idle_flow_timeout')
         self.netFlow_sampling_rate = self.module.params['net_flow'].get('sampling_rate')
@@ -533,11 +539,13 @@ class VMwareDvSwitch(PyVmomi):
                 results['net_flow_idle_flow_timeout'] = self.netFlow_idle_flow_timeout
                 results['net_flow_sampling_rate'] = self.netFlow_sampling_rate
                 results['net_flow_internal_flows_only'] = self.netFlow_internal_flows_only
+                results['net_flow_switch_ip'] = self.netFlow_switch_ip
             result = self.check_netFlow_config()
 
-            changed_netFlow = result[1]
+            changed_netFlow = result[2]
             if changed_netFlow:
                 spec.ipfixConfig = result[0]
+                spec.switchIpAddress = result[1]
 
             if changed_multicast or changed_network_policy or changed_netFlow:
                 self.update_dvs_config(self.dvs, spec)
@@ -667,15 +675,22 @@ class VMwareDvSwitch(PyVmomi):
     def check_netFlow_config(self):
         """Check NetFlow config"""
         changed = changed_collectorIpAddress = changed_collectorPort = changed_observationDomainId = \
-            changed_activeFlowTimeout = changed_idleFlowTimeout = changed_samplingRate = changed_internalFlowsOnly = False
+            changed_activeFlowTimeout = changed_idleFlowTimeout = changed_samplingRate = changed_internalFlowsOnly = \
+            changed_switchIpAddress = False
         collectorIpAddress_previous = collectorPort_previous = observationDomainId_previous = activeFlowTimeout_previous = \
-            idleFlowTimeout_previous = samplingRate_previous = internalFlowsOnly_previous = None
+            idleFlowTimeout_previous = samplingRate_previous = internalFlowsOnly_previous = switchIpAddress_previous = None
 
         current_config = self.dvs.config.ipfixConfig
         if current_config is None:
             new_config = vim.dvs.VmwareDistributedVirtualSwitch.IpfixConfig()
         else:
             new_config = current_config
+        current_switchIpAddress = self.dvs.config.switchIpAddress
+        if current_switchIpAddress is None:
+            new_config_spec = vim.dvs.VmwareDistributedVirtualSwitch.ConfigSpec()
+            new_switchIpAddress = new_config_spec.switchIpAddress
+        else:
+            new_switchIpAddress = current_switchIpAddress
 
         if self.netFlow_collector_ip is not None:
             if current_config.collectorIpAddress != self.netFlow_collector_ip:
@@ -706,11 +721,16 @@ class VMwareDvSwitch(PyVmomi):
                 changed = changed_internalFlowsOnly = True
                 internalFlowsOnly_previous = current_config.internalFlowsOnly
                 new_config.internalFlowsOnly = self.netFlow_internal_flows_only
+            if self.netFlow_switch_ip is not None and current_switchIpAddress != self.netFlow_switch_ip:
+                changed = changed_switchIpAddress = True
+                switchIpAddress_previous = current_switchIpAddress
+                new_switchIpAddress = self.netFlow_switch_ip
 
-        return (new_config, changed, changed_collectorIpAddress, collectorIpAddress_previous,
+        return (new_config, new_switchIpAddress, changed, changed_collectorIpAddress, collectorIpAddress_previous,
                 changed_collectorPort, collectorPort_previous, changed_observationDomainId, observationDomainId_previous,
                 changed_activeFlowTimeout, activeFlowTimeout_previous, changed_idleFlowTimeout, idleFlowTimeout_previous,
-                changed_samplingRate, samplingRate_previous, changed_internalFlowsOnly, internalFlowsOnly_previous)
+                changed_samplingRate, samplingRate_previous, changed_internalFlowsOnly, internalFlowsOnly_previous,
+                changed_switchIpAddress, switchIpAddress_previous)
 
     def exit_unchanged(self):
         """Exit with status message"""
@@ -725,6 +745,7 @@ class VMwareDvSwitch(PyVmomi):
         changed = True
         results = dict(changed=changed)
         results['dvswitch'] = self.switch_name
+
         if self.module.check_mode:
             results['result'] = "DVS would be deleted"
         else:
@@ -742,6 +763,7 @@ class VMwareDvSwitch(PyVmomi):
         results = dict(changed=changed)
         results['dvswitch'] = self.switch_name
         changed_list = []
+        message = ''
 
         config_spec = vim.dvs.VmwareDistributedVirtualSwitch.ConfigSpec()
         # Use the same version in the new spec; The version will be increased by one by the API automatically
@@ -885,6 +907,7 @@ class VMwareDvSwitch(PyVmomi):
                 config_spec.defaultPortConfig.macManagementPolicy = policy
 
         # Check switch version
+        spec_product = None
         if self.switch_version:
             results['version'] = self.switch_version
             if self.dvs.config.productInfo.version != self.switch_version:
@@ -907,10 +930,12 @@ class VMwareDvSwitch(PyVmomi):
             results['net_flow_idle_flow_timeout'] = self.netFlow_idle_flow_timeout
             results['net_flow_sampling_rate'] = self.netFlow_sampling_rate
             results['net_flow_internal_flows_only'] = self.netFlow_internal_flows_only
-        (ipfixConfig, changed_netFlow, changed_collectorIpAddress, collectorIpAddress_previous,
-         changed_collectorPort, collectorPort_previous, changed_observationDomainId, observationDomainId_previous,
-         changed_activeFlowTimeout, activeFlowTimeout_previous, changed_idleFlowTimeout, idleFlowTimeout_previous,
-         changed_samplingRate, samplingRate_previous, changed_internalFlowsOnly, internalFlowsOnly_previous) = self.check_netFlow_config()
+            results['net_flow_switch_ip'] = self.netFlow_switch_ip
+
+        (ipfixConfig, switchIpAddress_netFlow, changed_netFlow, changed_collectorIpAddress, collectorIpAddress_previous,
+         changed_collectorPort, collectorPort_previous, changed_observationDomainId, observationDomainId_previous, changed_activeFlowTimeout,
+         activeFlowTimeout_previous, changed_idleFlowTimeout, idleFlowTimeout_previous, changed_samplingRate, samplingRate_previous,
+         changed_internalFlowsOnly, internalFlowsOnly_previous, changed_switchIpAddress, switchIpAddress_previous) = self.check_netFlow_config()
         if changed_netFlow:
             changed = changed_settings = True
             changed_list.append("netFlow")
@@ -928,8 +953,11 @@ class VMwareDvSwitch(PyVmomi):
                 results['net_flow_sampling_rate_previous'] = samplingRate_previous
             if changed_internalFlowsOnly:
                 results['net_flow_internal_flows_only_previous'] = internalFlowsOnly_previous
+            if changed_switchIpAddress:
+                results['net_flow_switch_ip_previous'] = switchIpAddress_previous
 
             config_spec.ipfixConfig = ipfixConfig
+            config_spec.switchIpAddress = switchIpAddress_netFlow
 
         if changed:
             if self.module.check_mode:
@@ -965,7 +993,7 @@ class VMwareDvSwitch(PyVmomi):
 
 def main():
     """Main"""
-    argument_spec = vmware_argument_spec()
+    argument_spec = base_argument_spec()
     argument_spec.update(
         dict(
             datacenter_name=dict(aliases=['datacenter']),
@@ -1022,6 +1050,7 @@ def main():
                     collector_ip=dict(type='str'),
                     collector_port=dict(type='int', default=0),
                     observation_domain_id=dict(type='int', default=0),
+                    switch_ip=dict(type='str'),
                     active_flow_timeout=dict(type='int', default=60),
                     idle_flow_timeout=dict(type='int', default=15),
                     sampling_rate=dict(type='int', default=4096),
