@@ -288,7 +288,7 @@ except ImportError:
     pass
 
 import copy
-from ansible.module_utils._text import to_native
+from ansible.module_utils.common.text.converters import to_native
 from ansible.module_utils.basic import AnsibleModule
 from ansible_collections.community.vmware.plugins.module_utils.vmware import PyVmomi, TaskError, wait_for_task
 from ansible_collections.community.vmware.plugins.module_utils._argument_spec import base_argument_spec
