@@ -88,7 +88,7 @@ options:
    snapshot_id:
      description:
      - Sets the snapshot id to manage.
-     - This param is available when O(state=absent).
+     - This param is available when O(state=absent) or O(state=revert).
      type: int
      version_added: 3.10.0
    description:
@@ -285,8 +285,9 @@ except ImportError:
     pass
 
 from ansible.module_utils.basic import AnsibleModule
-from ansible.module_utils._text import to_native
-from ansible_collections.community.vmware.plugins.module_utils.vmware import PyVmomi, list_snapshots, vmware_argument_spec
+from ansible.module_utils.common.text.converters import to_native
+from ansible_collections.community.vmware.plugins.module_utils.vmware import PyVmomi, list_snapshots
+from ansible_collections.community.vmware.plugins.module_utils._argument_spec import base_argument_spec
 
 
 class PyVmomiHelper(PyVmomi):
@@ -435,7 +436,7 @@ class PyVmomiHelper(PyVmomi):
 
 
 def main():
-    argument_spec = vmware_argument_spec()
+    argument_spec = base_argument_spec()
     argument_spec.update(
         state=dict(default='present', choices=['present', 'absent', 'revert', 'remove_all']),
         name=dict(type='str'),
