@@ -2,7 +2,8 @@
 # -*- coding: utf-8 -*-
 
 # Copyright: (c) 2017, Davis Phillips davis.phillips@gmail.com
-# GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
+# GNU General Public License v3.0+ (see LICENSES/GPL-3.0-or-later.txt or https://www.gnu.org/licenses/gpl-3.0.txt)
+# SPDX-License-Identifier: GPL-3.0-or-later
 
 from __future__ import absolute_import, division, print_function
 __metaclass__ = type
@@ -16,47 +17,40 @@ description:
     - This module can be used to add/remove a resource pool to/from vCenter
 author:
 - Davis Phillips (@dav1x)
-notes:
-    - Tested on vSphere 6.5
-requirements:
-    - "python >= 2.6"
-    - PyVmomi
 options:
     datacenter:
         description:
             - Name of the datacenter.
-        required: True
+        required: true
         type: str
     cluster:
         description:
             - Name of the cluster to configure the resource pool.
-            - This parameter is required if C(esxi_hostname) or C(parent_resource_pool) is not specified.
-            - The C(cluster), C(esxi_hostname) and C(parent_resource_pool) parameters are mutually exclusive.
+            - This parameter is required if O(esxi_hostname) or O(parent_resource_pool) is not specified.
+            - The O(cluster), O(esxi_hostname) and O(parent_resource_pool) parameters are mutually exclusive.
         type: str
     esxi_hostname:
         description:
             - Name of the host to configure the resource pool.
             - The host must not be member of a cluster.
-            - This parameter is required if C(cluster) or C(parent_resource_pool) is not specified.
-            - The C(cluster), C(esxi_hostname) and C(parent_resource_pool) parameters are mutually exclusive.
+            - This parameter is required if O(cluster) or O(parent_resource_pool) is not specified.
+            - The O(cluster), O(esxi_hostname) and O(parent_resource_pool) parameters are mutually exclusive.
         type: str
-        version_added: '1.5.0'
     parent_resource_pool:
         description:
             - Name of the parent resource pool.
-            - This parameter is required if C(cluster) or C(esxi_hostname) is not specified.
-            - The C(cluster), C(esxi_hostname) and C(parent_resource_pool) parameters are mutually exclusive.
+            - This parameter is required if O(cluster) or O(esxi_hostname) is not specified.
+            - The O(cluster), O(esxi_hostname) and O(parent_resource_pool) parameters are mutually exclusive.
         type: str
-        version_added: '1.9.0'
     resource_pool:
         description:
             - Resource pool name to manage.
-        required: True
+        required: true
         type: str
     cpu_expandable_reservations:
         description:
             - In a resource pool with an expandable reservation, the reservation on a resource pool can grow beyond the specified value.
-        default: True
+        default: true
         type: bool
     cpu_reservation:
         description:
@@ -82,14 +76,13 @@ options:
     cpu_allocation_shares:
         description:
             - The number of cpu shares allocated.
-            - This value is only set if I(cpu_shares) is set to C(custom).
+            - This value is only set if O(cpu_shares=custom).
         type: int
         default: 4000
-        version_added: '1.4.0'
     mem_expandable_reservations:
         description:
             - In a resource pool with an expandable reservation, the reservation on a resource pool can grow beyond the specified value.
-        default: True
+        default: true
         type: bool
     mem_reservation:
         description:
@@ -115,10 +108,9 @@ options:
     mem_allocation_shares:
         description:
             - The number of memory shares allocated.
-            - This value is only set if I(mem_shares) is set to C(custom).
+            - This value is only set if O(mem_shares=custom).
         type: int
         default: 163840
-        version_added: '1.4.0'
     state:
         description:
             - Add or remove the resource pool
@@ -200,13 +192,13 @@ resource_pool_config:
 
 try:
     from pyVmomi import vim, vmodl
-    HAS_PYVMOMI = True
 except ImportError:
-    HAS_PYVMOMI = False
+    pass
 
-from ansible.module_utils._text import to_native
-from ansible_collections.community.vmware.plugins.module_utils.vmware import get_all_objs, vmware_argument_spec, find_datacenter_by_name, \
+from ansible.module_utils.common.text.converters import to_native
+from ansible_collections.community.vmware.plugins.module_utils.vmware import get_all_objs, find_datacenter_by_name, \
     find_cluster_by_name, find_object_by_name, wait_for_task, find_resource_pool_by_name, PyVmomi
+from ansible_collections.community.vmware.plugins.module_utils._argument_spec import base_argument_spec
 from ansible.module_utils.basic import AnsibleModule
 
 
@@ -452,7 +444,7 @@ class VMwareResourcePool(PyVmomi):
 
 
 def main():
-    argument_spec = vmware_argument_spec()
+    argument_spec = base_argument_spec()
     argument_spec.update(dict(datacenter=dict(required=True, type='str'),
                               cluster=dict(type='str', required=False),
                               esxi_hostname=dict(type='str', required=False),
@@ -487,9 +479,6 @@ def main():
                            ],
                            supports_check_mode=True)
 
-    if not HAS_PYVMOMI:
-        module.fail_json(msg='pyvmomi is required for this module')
-
     vmware_rp = VMwareResourcePool(module)
     vmware_rp.process_state()
 
