@@ -142,7 +142,7 @@ except ImportError:
     pass
 
 from ansible.module_utils.basic import AnsibleModule
-from ansible.module_utils._text import to_native
+from ansible.module_utils.common.text.converters import to_native
 from ansible_collections.community.vmware.plugins.module_utils.vmware import (
     PyVmomi, wait_for_task,
     find_vm_by_id, find_cluster_by_name, find_datacenter_by_name)
