@@ -16,7 +16,7 @@ import pytest
 import os
 from ansible_collections.dellemc.openmanage.plugins.modules import dellemc_idrac_storage_volume
 from ansible_collections.dellemc.openmanage.tests.unit.plugins.modules.common import FakeAnsibleModule
-from mock import MagicMock, Mock
+from unittest.mock import MagicMock, Mock
 from pytest import importorskip
 
 importorskip("omsdk.sdkfile")
@@ -221,7 +221,7 @@ class TestStorageVolume(FakeAnsibleModule):
                                                   mocker):
         idrac_default_args.update({"share_name": "sharename", "state": "create", "controller_id": "XYZ123",
                                    "capacity": 1.4, "stripe_size": 1, "volumes": [{"drives": {"id": ["data"],
-                                                                                              "location":[1]}}]})
+                                                                                              "location": [1]}}]})
         with pytest.raises(ValueError) as ex:
             self.module._validate_options(idrac_default_args)
         assert "Either {0} or {1} is allowed".format("id", "location") == str(ex.value)
