@@ -95,65 +95,74 @@ options:
         suboptions:
             name:
                 type: str
-                description: No description.
+                description: Name.
                 required: true
             oid:
                 type: int
-                description: No description.
-            package settings:
+                description: Oid.
+            package_settings:
+                aliases: ['package settings']
                 type: dict
-                description: Deprecated, please rename it to package_settings.
+                description: Package settings.
                 suboptions:
-                    central-nat:
+                    central_nat:
+                        aliases: ['central-nat']
                         type: str
-                        description: Deprecated, please rename it to central_nat.
+                        description: Central nat.
                         choices:
                             - 'disable'
                             - 'enable'
-                    consolidated-firewall-mode:
+                    consolidated_firewall_mode:
+                        aliases: ['consolidated-firewall-mode']
                         type: str
-                        description: Deprecated, please rename it to consolidated_firewall_mode.
+                        description: Consolidated firewall mode.
                         choices:
                             - 'disable'
                             - 'enable'
-                    fwpolicy-implicit-log:
+                    fwpolicy_implicit_log:
+                        aliases: ['fwpolicy-implicit-log']
                         type: str
-                        description: Deprecated, please rename it to fwpolicy_implicit_log.
+                        description: Fwpolicy implicit log.
                         choices:
                             - 'disable'
                             - 'enable'
-                    fwpolicy6-implicit-log:
+                    fwpolicy6_implicit_log:
+                        aliases: ['fwpolicy6-implicit-log']
                         type: str
-                        description: Deprecated, please rename it to fwpolicy6_implicit_log.
+                        description: Fwpolicy6 implicit log.
                         choices:
                             - 'disable'
                             - 'enable'
-                    inspection-mode:
+                    inspection_mode:
+                        aliases: ['inspection-mode']
                         type: str
-                        description: Deprecated, please rename it to inspection_mode.
+                        description: Inspection mode.
                         choices:
                             - 'proxy'
                             - 'flow'
-                    ngfw-mode:
+                    ngfw_mode:
+                        aliases: ['ngfw-mode']
                         type: str
-                        description: Deprecated, please rename it to ngfw_mode.
+                        description: Ngfw mode.
                         choices:
                             - 'profile-based'
                             - 'policy-based'
-                    policy-offload-level:
+                    policy_offload_level:
+                        aliases: ['policy-offload-level']
                         type: str
-                        description: Deprecated, please rename it to policy_offload_level.
+                        description: Policy offload level.
                         choices:
                             - 'disable'
                             - 'default'
                             - 'dos-offload'
                             - 'full-offload'
-                    ssl-ssh-profile:
+                    ssl_ssh_profile:
+                        aliases: ['ssl-ssh-profile']
                         type: str
-                        description: Deprecated, please rename it to ssl_ssh_profile.
+                        description: Ssl ssh profile.
             type:
                 type: str
-                description: No description.
+                description: Type.
                 choices:
                     - 'pblock'
 '''
@@ -162,6 +171,7 @@ EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -170,26 +180,26 @@ EXAMPLES = '''
     - name: Policy block adom
       fortinet.fortimanager.fmgr_pm_pblock_obj:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         adom: <your own value>
         pkg_path: <your own value>
         state: present # <value in [present, absent]>
         pm_pblock_obj:
-          name: <string>
-          oid: <integer>
-          package_settings:
-            central_nat: <value in [disable, enable]>
-            consolidated_firewall_mode: <value in [disable, enable]>
-            fwpolicy_implicit_log: <value in [disable, enable]>
-            fwpolicy6_implicit_log: <value in [disable, enable]>
-            inspection_mode: <value in [proxy, flow]>
-            ngfw_mode: <value in [profile-based, policy-based]>
-            policy_offload_level: <value in [disable, default, dos-offload, ...]>
-            ssl_ssh_profile: <string>
-          type: <value in [pblock]>
+          name: "your value" # Required variable, string
+          # oid: <integer>
+          # package_settings:
+          #   central_nat: <value in [disable, enable]>
+          #   consolidated_firewall_mode: <value in [disable, enable]>
+          #   fwpolicy_implicit_log: <value in [disable, enable]>
+          #   fwpolicy6_implicit_log: <value in [disable, enable]>
+          #   inspection_mode: <value in [proxy, flow]>
+          #   ngfw_mode: <value in [profile-based, policy-based]>
+          #   policy_offload_level: <value in [disable, default, dos-offload, ...]>
+          #   ssl_ssh_profile: <string>
+          # type: <value in [pblock]>
 '''
 
 RETURN = '''
@@ -233,21 +243,14 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/pm/pblock/adom/{adom}/{pkg_path}'
     ]
-
-    perobject_jrpc_urls = [
-        '/pm/pblock/adom/{adom}/{pkg_path}'
-    ]
-
     url_params = ['adom', 'pkg_path']
     module_primary_key = 'name'
     module_arg_spec = {
@@ -260,6 +263,7 @@ def main():
                 'name': {'v_range': [['7.0.3', '']], 'required': True, 'type': 'str'},
                 'oid': {'v_range': [['7.0.3', '']], 'type': 'int'},
                 'package settings': {
+                    'v_range': [['7.0.3', '']],
                     'type': 'dict',
                     'options': {
                         'central-nat': {'v_range': [['7.0.3', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
@@ -278,7 +282,6 @@ def main():
                 },
                 'type': {'v_range': [['7.0.3', '']], 'choices': ['pblock'], 'type': 'str'}
             }
-
         }
     }
 
@@ -287,17 +290,15 @@ def main():
     params_validation_blob = []
     check_galaxy_version(module_arg_spec)
     module = AnsibleModule(argument_spec=check_parameter_bypass(module_arg_spec, 'pm_pblock_obj'),
-                           supports_check_mode=False)
+                           supports_check_mode=True)
 
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    connection.set_option('access_token', module.params.get('access_token', None))
-    connection.set_option('enable_log', module.params.get('enable_log', False))
-    connection.set_option('forticloud_access_token', module.params.get('forticloud_access_token', None))
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('full crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_curd(argument_specs=module_arg_spec)
+    fmgr.process_crud()
 
     module.exit_json(meta=module.params)
 
