@@ -630,6 +630,7 @@ EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -638,130 +639,129 @@ EXAMPLES = '''
     - name: Configure SSL VPN.
       fortinet.fortimanager.fmgr_vpn_ssl_settings:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         device: <your own value>
         vdom: <your own value>
         vpn_ssl_settings:
-          algorithm: <value in [default, high, low, ...]>
-          auth_session_check_source_ip: <value in [disable, enable]>
-          auth_timeout: <integer>
-          authentication_rule:
-            -
-              auth: <value in [any, local, radius, ...]>
-              cipher: <value in [any, high, medium]>
-              client_cert: <value in [disable, enable]>
-              groups: <list or string>
-              id: <integer>
-              portal: <string>
-              realm: <string>
-              source_address: <list or string>
-              source_address_negate: <value in [disable, enable]>
-              source_address6: <list or string>
-              source_address6_negate: <value in [disable, enable]>
-              source_interface: <list or string>
-              user_peer: <string>
-              users: <list or string>
-          auto_tunnel_static_route: <value in [disable, enable]>
-          banned_cipher:
-            - "RSA"
-            - "DH"
-            - "DHE"
-            - "ECDH"
-            - "ECDHE"
-            - "DSS"
-            - "ECDSA"
-            - "AES"
-            - "AESGCM"
-            - "CAMELLIA"
-            - "3DES"
-            - "SHA1"
-            - "SHA256"
-            - "SHA384"
-            - "STATIC"
-            - "CHACHA20"
-            - "ARIA"
-            - "AESCCM"
-          check_referer: <value in [disable, enable]>
-          default_portal: <string>
-          deflate_compression_level: <integer>
-          deflate_min_data_size: <integer>
-          dns_server1: <string>
-          dns_server2: <string>
-          dns_suffix: <string>
-          dtls_hello_timeout: <integer>
-          dtls_max_proto_ver: <value in [dtls1-0, dtls1-2]>
-          dtls_min_proto_ver: <value in [dtls1-0, dtls1-2]>
-          dtls_tunnel: <value in [disable, enable]>
-          encode_2f_sequence: <value in [disable, enable]>
-          encrypt_and_store_password: <value in [disable, enable]>
-          force_two_factor_auth: <value in [disable, enable]>
-          header_x_forwarded_for: <value in [pass, add, remove]>
-          hsts_include_subdomains: <value in [disable, enable]>
-          http_compression: <value in [disable, enable]>
-          http_only_cookie: <value in [disable, enable]>
-          http_request_body_timeout: <integer>
-          http_request_header_timeout: <integer>
-          https_redirect: <value in [disable, enable]>
-          idle_timeout: <integer>
-          ipv6_dns_server1: <string>
-          ipv6_dns_server2: <string>
-          ipv6_wins_server1: <string>
-          ipv6_wins_server2: <string>
-          login_attempt_limit: <integer>
-          login_block_time: <integer>
-          login_timeout: <integer>
-          port: <integer>
-          port_precedence: <value in [disable, enable]>
-          reqclientcert: <value in [disable, enable]>
-          route_source_interface: <value in [disable, enable]>
-          servercert: <string>
-          source_address: <list or string>
-          source_address_negate: <value in [disable, enable]>
-          source_address6: <list or string>
-          source_address6_negate: <value in [disable, enable]>
-          source_interface: <list or string>
-          ssl_client_renegotiation: <value in [disable, enable]>
-          ssl_insert_empty_fragment: <value in [disable, enable]>
-          ssl_max_proto_ver: <value in [tls1-0, tls1-1, tls1-2, ...]>
-          ssl_min_proto_ver: <value in [tls1-0, tls1-1, tls1-2, ...]>
-          tlsv1_0: <value in [disable, enable]>
-          tlsv1_1: <value in [disable, enable]>
-          tlsv1_2: <value in [disable, enable]>
-          tlsv1_3: <value in [disable, enable]>
-          transform_backward_slashes: <value in [disable, enable]>
-          tunnel_connect_without_reauth: <value in [disable, enable]>
-          tunnel_ip_pools: <list or string>
-          tunnel_ipv6_pools: <list or string>
-          tunnel_user_session_timeout: <integer>
-          unsafe_legacy_renegotiation: <value in [disable, enable]>
-          url_obscuration: <value in [disable, enable]>
-          user_peer: <string>
-          wins_server1: <string>
-          wins_server2: <string>
-          x_content_type_options: <value in [disable, enable]>
-          sslv3: <value in [disable, enable]>
-          ssl_big_buffer: <value in [disable, enable]>
-          client_sigalgs: <value in [no-rsa-pss, all]>
-          ciphersuite:
-            - "TLS-AES-128-GCM-SHA256"
-            - "TLS-AES-256-GCM-SHA384"
-            - "TLS-CHACHA20-POLY1305-SHA256"
-            - "TLS-AES-128-CCM-SHA256"
-            - "TLS-AES-128-CCM-8-SHA256"
-          dual_stack_mode: <value in [disable, enable]>
-          tunnel_addr_assigned_method: <value in [first-available, round-robin]>
-          browser_language_detection: <value in [disable, enable]>
-          saml_redirect_port: <integer>
-          status: <value in [disable, enable]>
-          web_mode_snat: <value in [disable, enable]>
-          ztna_trusted_client: <value in [disable, enable]>
-          dtls_heartbeat_fail_count: <integer>
-          dtls_heartbeat_idle_timeout: <integer>
-          dtls_heartbeat_interval: <integer>
-          server_hostname: <string>
+          # algorithm: <value in [default, high, low, ...]>
+          # auth_session_check_source_ip: <value in [disable, enable]>
+          # auth_timeout: <integer>
+          # authentication_rule:
+          #   - auth: <value in [any, local, radius, ...]>
+          #     cipher: <value in [any, high, medium]>
+          #     client_cert: <value in [disable, enable]>
+          #     groups: <list or string>
+          #     id: <integer>
+          #     portal: <string>
+          #     realm: <string>
+          #     source_address: <list or string>
+          #     source_address_negate: <value in [disable, enable]>
+          #     source_address6: <list or string>
+          #     source_address6_negate: <value in [disable, enable]>
+          #     source_interface: <list or string>
+          #     user_peer: <string>
+          #     users: <list or string>
+          # auto_tunnel_static_route: <value in [disable, enable]>
+          # banned_cipher:
+          #   - "RSA"
+          #   - "DH"
+          #   - "DHE"
+          #   - "ECDH"
+          #   - "ECDHE"
+          #   - "DSS"
+          #   - "ECDSA"
+          #   - "AES"
+          #   - "AESGCM"
+          #   - "CAMELLIA"
+          #   - "3DES"
+          #   - "SHA1"
+          #   - "SHA256"
+          #   - "SHA384"
+          #   - "STATIC"
+          #   - "CHACHA20"
+          #   - "ARIA"
+          #   - "AESCCM"
+          # check_referer: <value in [disable, enable]>
+          # default_portal: <string>
+          # deflate_compression_level: <integer>
+          # deflate_min_data_size: <integer>
+          # dns_server1: <string>
+          # dns_server2: <string>
+          # dns_suffix: <string>
+          # dtls_hello_timeout: <integer>
+          # dtls_max_proto_ver: <value in [dtls1-0, dtls1-2]>
+          # dtls_min_proto_ver: <value in [dtls1-0, dtls1-2]>
+          # dtls_tunnel: <value in [disable, enable]>
+          # encode_2f_sequence: <value in [disable, enable]>
+          # encrypt_and_store_password: <value in [disable, enable]>
+          # force_two_factor_auth: <value in [disable, enable]>
+          # header_x_forwarded_for: <value in [pass, add, remove]>
+          # hsts_include_subdomains: <value in [disable, enable]>
+          # http_compression: <value in [disable, enable]>
+          # http_only_cookie: <value in [disable, enable]>
+          # http_request_body_timeout: <integer>
+          # http_request_header_timeout: <integer>
+          # https_redirect: <value in [disable, enable]>
+          # idle_timeout: <integer>
+          # ipv6_dns_server1: <string>
+          # ipv6_dns_server2: <string>
+          # ipv6_wins_server1: <string>
+          # ipv6_wins_server2: <string>
+          # login_attempt_limit: <integer>
+          # login_block_time: <integer>
+          # login_timeout: <integer>
+          # port: <integer>
+          # port_precedence: <value in [disable, enable]>
+          # reqclientcert: <value in [disable, enable]>
+          # route_source_interface: <value in [disable, enable]>
+          # servercert: <string>
+          # source_address: <list or string>
+          # source_address_negate: <value in [disable, enable]>
+          # source_address6: <list or string>
+          # source_address6_negate: <value in [disable, enable]>
+          # source_interface: <list or string>
+          # ssl_client_renegotiation: <value in [disable, enable]>
+          # ssl_insert_empty_fragment: <value in [disable, enable]>
+          # ssl_max_proto_ver: <value in [tls1-0, tls1-1, tls1-2, ...]>
+          # ssl_min_proto_ver: <value in [tls1-0, tls1-1, tls1-2, ...]>
+          # tlsv1_0: <value in [disable, enable]>
+          # tlsv1_1: <value in [disable, enable]>
+          # tlsv1_2: <value in [disable, enable]>
+          # tlsv1_3: <value in [disable, enable]>
+          # transform_backward_slashes: <value in [disable, enable]>
+          # tunnel_connect_without_reauth: <value in [disable, enable]>
+          # tunnel_ip_pools: <list or string>
+          # tunnel_ipv6_pools: <list or string>
+          # tunnel_user_session_timeout: <integer>
+          # unsafe_legacy_renegotiation: <value in [disable, enable]>
+          # url_obscuration: <value in [disable, enable]>
+          # user_peer: <string>
+          # wins_server1: <string>
+          # wins_server2: <string>
+          # x_content_type_options: <value in [disable, enable]>
+          # sslv3: <value in [disable, enable]>
+          # ssl_big_buffer: <value in [disable, enable]>
+          # client_sigalgs: <value in [no-rsa-pss, all]>
+          # ciphersuite:
+          #   - "TLS-AES-128-GCM-SHA256"
+          #   - "TLS-AES-256-GCM-SHA384"
+          #   - "TLS-CHACHA20-POLY1305-SHA256"
+          #   - "TLS-AES-128-CCM-SHA256"
+          #   - "TLS-AES-128-CCM-8-SHA256"
+          # dual_stack_mode: <value in [disable, enable]>
+          # tunnel_addr_assigned_method: <value in [first-available, round-robin]>
+          # browser_language_detection: <value in [disable, enable]>
+          # saml_redirect_port: <integer>
+          # status: <value in [disable, enable]>
+          # web_mode_snat: <value in [disable, enable]>
+          # ztna_trusted_client: <value in [disable, enable]>
+          # dtls_heartbeat_fail_count: <integer>
+          # dtls_heartbeat_idle_timeout: <integer>
+          # dtls_heartbeat_interval: <integer>
+          # server_hostname: <string>
 '''
 
 RETURN = '''
@@ -823,7 +823,7 @@ def main():
             'v_range': [['6.2.6', '6.2.13'], ['6.4.2', '']],
             'options': {
                 'algorithm': {
-                    'v_range': [['6.2.6', '6.2.13'], ['6.4.2', '7.2.1'], ['7.2.6', '7.2.9'], ['7.4.3', '']],
+                    'v_range': [['6.2.6', '6.2.13'], ['6.4.2', '7.2.1'], ['7.2.6', '7.2.11'], ['7.4.3', '']],
                     'choices': ['default', 'high', 'low', 'medium'],
                     'type': 'str'
                 },
