@@ -27,6 +27,7 @@ attributes:
     support: full
 extends_documentation_fragment:
 - hitachivantara.vspone_block.common.gateway_note
+- hitachivantara.vspone_block.common.connection_info
 options:
   storage_system_info:
     description: Information about the storage system. This field is an optional field.
@@ -37,27 +38,6 @@ options:
         description: The serial number of the storage system.
         type: str
         required: false
-  connection_info:
-    description: Information required to establish a connection to the storage system.
-    type: dict
-    required: true
-    suboptions:
-      address:
-        description: IP address or hostname of the storage system.
-        type: str
-        required: true
-      username:
-        description: Username for authentication. This is a required field if api_token is not provided.
-        type: str
-        required: false
-      password:
-        description: Password for authentication. This is a required field if api_token is not provided.
-        type: str
-        required: false
-      api_token:
-        description: This field is used to pass the value of the lock token to operate on locked resources.
-        type: str
-        required: false
   spec:
     description: Specification for the NVM subsystems facts to be gathered.
     type: dict
@@ -65,10 +45,12 @@ options:
     suboptions:
       name:
         description: The name of the NVM subsystem to retrieve.
+          Required for the Get NVM Subsystems by name task.
         type: str
         required: false
       id:
         description: The ID of the NVM subsystem to retrieve.
+          Required for the Get NVM subsystems by ID task.
         type: int
         required: false
 """
